# -*- coding: UTF-8 -*-

from artix.common.py2to3utils import configparser
import glob
import os


class Config:
    def __init__(self):
        self.__isCash = os.environ.get('SERVICE_LOCATION', 'cash') == 'cash'
        self.__config = None
        self.__conffiles = None
        self.__isValid = False

    def getInt(self, section, option, defaultValue=0):
        if self.__config.has_section(section) and self.__config.has_option(section, option):
            return self.__config.getint(section, option)
        return defaultValue

    def getBool(self, section, option, defaultValue=False):
        if self.__config.has_section(section) and self.__config.has_option(section, option):
            try:
                return self.__config.getboolean(section, option)
            except:
                return defaultValue
        return defaultValue

    def getString(self, section, option, defaultValue=''):
        if self.__config.has_section(section) and self.__config.has_option(section, option):
            return self.__config.get(section, option)
        return defaultValue

    def getOptions(self, section, defaultValue=[]):
        """ Получение списка имён опций конкретной секции
        :return Список строк
        """
        return self.__config.options(section) if self.__config.has_section(section) else defaultValue

    def isCash(self):
        return self.__isCash

    def isValid(self):
        return self.__isValid

    def getConffiles(self):
        return self.__conffiles

    def read(self, path, additionalDir=None):
        """ Чтение конфигурационных файлов
        :param str path - путь до конфигурационного файла
        :param str additionalDir - путь до директории с конфигурационными файлами(*.ini)
        :return bool - True, если список считанных файлов равен ожидаемому списку для чтения
        """
        self.__config = configparser.RawConfigParser()
        self.__conffiles = [path]
        if additionalDir and os.path.isdir(additionalDir):
            self.__conffiles.extend(glob.glob(os.path.join(additionalDir, '*.ini')))
        self.__isValid = len(self.__config.read(self.__conffiles)) == len(self.__conffiles)
        return self.__isValid

    def reread(self):
        self.__isValid = len(self.__config.read(self.__conffiles)) == len(self.__conffiles)
